#!/bin/bash

if [ -x "/opt/zimbra" ]; then
## Postfix mailqueue monitoring
## Determine the number of mails and their size in several postfix mail queues
postfix_queue_dir="/opt/zimbra/data/postfix/spool"
if [ -n "$postfix_queue_dir" ]; then
        echo '<<<postfix_mailq>>>'
        echo "[[[${2}]]]"
        for queue in deferred active; do
                count=$(find "${postfix_queue_dir}/$queue" -type f | wc -l)
                size=$(du -s "${postfix_queue_dir}/$queue" | awk '{print $1 }')
                if [ -z "$size" ]; then
                        size=0
                fi
                if [ -z "$count" ]; then
                        echo "Mail queue is empty"
                else
                        echo "QUEUE_${queue} $size $count"
                fi
        done
fi


## Zimbra Services monitoring
## Determine if all zimbra services are running
if [ -n "/opt/zimbra/bin/zmcontrol" ]; then
    echo '<<<zimbra>>>'
    su - zimbra -c '/opt/zimbra/bin/zmcontrol status'
fi


## Zimbra MySQL monitoring
## Rewrite of CheckMK mk_mysql agent plugin to work with zimbra
function do_query() {

  # we use the sockets full name as instance name:
  INSTANCE_HEADER="[[$2]]"

  # Check if /opt/zimbra/bin/mysqld is running and root password setup
  echo "<<<mysql_ping>>>"
  echo "$INSTANCE_HEADER"
  /opt/zimbra/bin/mysqladmin ${1:+--socket="$1"} ping 2>&1 || return

  echo "<<<mysql>>>"
  echo "$INSTANCE_HEADER"
  /opt/zimbra/bin/mysql ${1:+--socket="$1"} -sN \
     -e "show global status ; show global variables ;"

  echo "<<<mysql_capacity>>>"
  echo "$INSTANCE_HEADER"
  /opt/zimbra/bin/mysql ${1:+--socket="$1"} -sN \
      -e "SELECT table_schema, sum(data_length + index_length), sum(data_free)
         FROM information_schema.TABLES WHERE table_schema NOT LIKE \"mboxgroup%\" GROUP BY table_schema"

  echo "<<<mysql_slave>>>"
  echo "$INSTANCE_HEADER"
  /opt/zimbra/bin/mysql ${1:+--socket="$1"} -s \
     -e "show slave status\G"

}

if type /opt/zimbra/bin/mysqladmin >/dev/null
then
  /opt/zimbra/bin/mysql_sockets=$(fgrep -h socket /etc/check_mk/mysql{.local,}.cfg | sed -ne 's/.*socket=\([^ ]*\).*/\1/p')
  alias=$(fgrep -h alias "$MK_CONFDIR"/mysql{.local,}.cfg | cut -d \" -f2)
  if [ -z "$mysql_sockets" ] ; then
    /opt/zimbra/bin/mysql_sockets=$(ps -fww -C /opt/zimbra/bin/mysqld | grep "socket" | sed -ne 's/.*socket=\([^ ]*\).*/\1/p')
  fi
  if [ -z "$mysql_sockets" ] ; then
    do_query "" "$alias"
  else
    for socket in $mysql_sockets ; do
      if [ -z "$alias" ] ; then
        do_query "$socket" "$socket"
      else
        do_query "$socket" "$alias"
      fi
    done
  fi

  # In async execution the cache file would be removed if the plugin exits with non-zero exit code.
  # Avoid this from happening, just because the last /opt/zimbra/bin/mysql command failed (due to missing permissions).
  exit 0
fi
fi