#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-

# (c) 2022 Siedl Networks GmbH
#          Rene Bayer <rene.bayer@siedl.net>

# This is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  This file is distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

from .agent_based_api.v1 import *

def parse_zimbra_servicestatus(string_table):
    host = "<Null>"
    section = {}

    for line in string_table:
        if line[0] == "Host":
            host = line[1]
            section[host] = {}
        if line[0] != "Host" and len(line) > 2:
            service = ""
            if len(line) >= 4:
                if line[-3] == 'is' and line[-2] == 'not':
                    for _ in line[:-3]:
                        service += _
                    section[host][service] = 'stopped'
                    continue
            for _ in line[:-1]:
                service += _
            section[host][service] = line[-1]
        elif line[0] != "Host" and len(line) <= 2:
            section[host][line[0]] = line[1]
    return section


def discover_zimbra_servicestatus(section):
    yield Service()


def check_zimbra_servicestatus(section):
    section = parse_zimbra_servicestatus(string_table=section)
    state = State.OK
    summary = "All Zimbra services up and running."
    details = ""

    for host, services in section.items():
        details += "Host: " + host
        for service, status in services.items():
            if status == 'Running':
                details += "\n\r(.) " + service
            if status != 'Running':
                details += "\n\r(!!) " + service
                summary = "Not all Zimbra services are up and running!"
                state = State.CRIT

    yield Result(state=state, summary=summary, details=details)

register.check_plugin(
    name="zimbra",
    service_name="Zimbra Services",
    #parse_function=parse_zimbra_servicestatus,
    discovery_function=discover_zimbra_servicestatus,
    check_function=check_zimbra_servicestatus
)